==========
hieronymus
==========

Overview
--------

Create a minimal python package.

Installation
------------

To install hieronymus, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install hieronymus

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/hieronymus/#files>`_
* `Source <https://github.com/johannes-programming/hieronymus>`_

Credits
-------
- Author: Johannes
- Email: johannes-programming@mailfence.com

Thank you for using hieronymus!